import * as React from 'react';
import { hot } from 'react-hot-loader'
import { Route, Router } from 'react-router';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

import { ThemeProvider } from '@romanjaros/treejs-components/styled';
import PageLayout from '@romanjaros/treejs-components/Layout';
import { IMenuItem } from '@romanjaros/treejs-components/Layout/types';

import ButtonPage from 'documentation/ButtonPage/components';
import CalendarPage from 'documentation/CalendarPage/components';
import CheckboxPage from 'documentation/CheckboxPage/components';
import GridPage from 'documentation/GridPage/components';
import ModalPage from 'documentation/ModalPage/components';
import RadioButtonPage from 'documentation/RadioButtonPage/components';
import SelectBoxPage from 'documentation/SelectBoxPage/components';
import DatePickerPage from 'documentation/DatePickerPage/components';
import TextFieldPage from 'documentation/TextFieldPage/components';
import TablePage from 'documentation/TablePage/components';
import FormsPage from 'documentation/FormsPage/components';
import WelcomePage from 'documentation/WelcomePage/components';
import FetchPage from 'documentation/FetchPage/components';
import SignInPage from 'documentation/ProfilePage/components/signin';
import SignOutPage from 'documentation/ProfilePage/components/signout';
import SliderPage from 'documentation/SliderPage/components';
import ToasterPage from 'documentation/ToasterPage/components';
import { THEME } from 'documentation/WelcomePage/constants';

import { MainStyle } from '../styles/App';
import { StyledUserName, StyledUserContainer } from '../styles/User';
import history from '../utils/history';


const UserComponent = () => {
	return (
		<StyledUserContainer>
			<FontAwesomeIcon size="2x" icon="user-circle" />
			<StyledUserName>Roman</StyledUserName>
		</StyledUserContainer>
	)
};

const App = (): React.ReactElement => {
	const leftMenuItems: IMenuItem[] = [
		{
			label: 'Components',
			subMenu: [
				{ label: 'Button', href: '/button' },
				{ label: 'Kalendář', href: '/calendar' },
				{ label: 'Checkbox', href: '/checkbox' },
				{ label: 'Grid', href: '/grid' },
				{ label: 'Modal', href: '/modal' },
				{ label: 'Radio', href: '/radioButton' },
				{ label: 'SelectBox', href: '/selectBox' },
				{ label: 'DatePicker', href: '/datePicker' },
				{ label: 'TextField', href: '/textField' },
				{ label: 'Table', href: '/table' },
				{ label: 'Forms', href: '/forms' },
				{ label: 'Slider', href: '/slider' },
				{ label: 'Toaster', href: '/toaster' },
			]
		},
		{
			label: 'API Middleware',
			subMenu: [
				{ label: 'Fetch', href: '/fetch' },
			]
		},
	];

	const topMenuItems: IMenuItem[] = [
		{ label: 'Home', href: '/' },
		{ label: 'New record', href: '/' },
	];

	const userMenuItems: IMenuItem[] = [
		{ label: 'Odhlásit se', href: '/signin' },
	];

	const themeName = window.localStorage.getItem(THEME) || 'main';
	const theme = require(`@romanjaros/treejs-components/themes/${themeName}`).default;

	return (
		<ThemeProvider theme={theme}>
			<MainStyle>
				<PageLayout
					history={history}
					leftMenuItems={leftMenuItems}
					topMenuItems={topMenuItems}
					userMenuItems={userMenuItems}
					enableLeftMenu
					enableUserMenu
					userComponent={<UserComponent />}
					logo={<div><FontAwesomeIcon icon="tree" /> js</div>}
				>
					<Router history={history}>
						<Route path="/" exact component={WelcomePage} />
						<Route path="/button" component={ButtonPage} />
						<Route path="/calendar" component={CalendarPage} />
						<Route path="/checkbox" component={CheckboxPage} />
						<Route path="/grid" component={GridPage} />
						<Route path="/modal" component={ModalPage} />
						<Route path="/radioButton" component={RadioButtonPage} />
						<Route path="/selectBox" component={SelectBoxPage} />
						<Route path="/datePicker" component={DatePickerPage} />
						<Route path="/textField" component={TextFieldPage} />
						<Route path="/table" component={TablePage} />
						<Route path="/forms" component={FormsPage} />
						<Route path="/fetch" component={FetchPage} />
						<Route path="/signin" component={SignInPage} />
						<Route path="/signout" component={SignOutPage} />
						<Route path="/slider" component={SliderPage} />
						<Route path="/toaster" component={ToasterPage} />
					</Router>
				</PageLayout>
			</MainStyle>
		</ThemeProvider>
	);
};

export default hot(module)(App);
