import * as React from 'react';

import { Grid, GridCol } from '@romanjaros/treejs-components/Grid';
import RadioButton from '@romanjaros/treejs-components/RadioButton';

import { generateDocumentationObject } from 'documentation/App/utils/documentation';
import DocTable from 'documentation/App/components/DocTable';

import { groups, children } from '../typedoc.json';

import { customRender } from './customRender';


const propDefinition = generateDocumentationObject(groups, children);

const RadioButtonPage = (): React.ReactElement => (
	<React.Fragment>
		<h2>RadioButton</h2>

		<h3>Normal</h3>
		<Grid>
			<GridCol size={3}>
				<RadioButton
					name="radioButtons"
					title="Normal"
					options={[
						{ name: 'item 1', code: 'item1' },
						{ name: 'item 2', code: 'item2' },
					]}
				/>
			</GridCol>
		</Grid>

		<h3>Horizontal</h3>
		<Grid>
			<GridCol size={3}>
				<RadioButton
					horizontal
					name="horizontalRadioButtons"
					title="Horizontal"
					options={[
						{ name: 'item 1', code: 'item1' },
						{ name: 'item 2', code: 'item2' },
					]}
				/>
			</GridCol>
		</Grid>

		<h3>Custom render</h3>
		<Grid>
			<GridCol size={3}>
				<RadioButton
					horizontal
					name="customRenderRadioButtons"
					title="Custom Render"
					options={[
						{ name: 'Právnická osoba', code: 'legal' },
						{ name: 'Fyzická osoba', code: 'natural' },
					]}
					customRender={customRender}
				/>
			</GridCol>
		</Grid>

		<h4>Props</h4>
		<DocTable propDefinition={propDefinition} />
	</React.Fragment>
);

export default RadioButtonPage;
