import * as React from 'react';
import OutsideClickHandler from 'react-outside-click-handler';

import { isNilOrEmpty } from '@romanjaros/treejs-utils';

import { IMenuItem } from '../types';
import { StyledUserMenuIcon, StyledUserMenuContainer, StyledUserMenuLabel } from '../style';


interface IProps {
	children: React.ReactElement;
	menuItems: IMenuItem[];
}

export const MenuDropdown = (props: IProps) => {
	const [open, setOpen] = React.useState(false);

	return (
		<OutsideClickHandler onOutsideClick={() => setOpen(false)}>
			<StyledUserMenuIcon onClick={() => setOpen(!open)}>
				{props.children}
			</StyledUserMenuIcon>
			{
				open && (
					<StyledUserMenuContainer>
						{
							!isNilOrEmpty(props.menuItems) && props.menuItems.map(
								({ label }, i) => (
									<StyledUserMenuLabel key={i}>{label}</StyledUserMenuLabel>
								)
							)
						}
					</StyledUserMenuContainer>
				)
			}
		</OutsideClickHandler>
	)
};

export default MenuDropdown;
