import * as React from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

import { isNilOrEmpty } from '@romanjaros/treejs-utils';

import { IMenuItem } from '../types';
import { StyledLeftMenuItem, StyledLeftMenuLabel, StyledLeftMenuIcon } from '../style';


interface IProps extends IMenuItem {
	isChild: boolean;
	onClick: (url: string) => void;
}

const handleOnClick = (props: IProps) => () => {
	if (!isNilOrEmpty(props.href)) {
		props.onClick(props.href);
	}
}

export const MenuItem = (props: IProps) => {
	const [open, setOpen] = React.useState(props.defaultOpen);

	return (
		<React.Fragment>
			<StyledLeftMenuItem isChild={props.isChild || false}>
				<StyledLeftMenuLabel onClick={handleOnClick(props)} showPointerCursor={!isNilOrEmpty(props.href)}>
					{props.label}
				</StyledLeftMenuLabel>
				{
					!isNilOrEmpty(props.subMenu) && (
						<StyledLeftMenuIcon onClick={() => setOpen(!open)} >
							<FontAwesomeIcon icon={open ? 'chevron-up' : 'chevron-down'} />
						</StyledLeftMenuIcon>
					)
				}
			</StyledLeftMenuItem>
			{
				!isNilOrEmpty(props.subMenu) && open && props.subMenu.map(
					(menuItem, i) => (
						<MenuItem
							key={i}
							isChild={true}
							onClick={props.onClick}
							{...menuItem}
						/>
					)
				)
			}
		</React.Fragment>
	)
};

export default MenuItem;
