import styled, { css } from '../styled';


export const StyledTopMenu = styled.div`
	height: 40px;

	display: flex;

	color: ${(p) => p.theme.primaryColor};

	padding: 10px 10px 10px 20px;
`;

export const StyledTopMenuItem = styled.div`
	margin: 10px;

	cursor: pointer;

	vertical-align: middle;
	white-space: nowrap
`;

export const StyledTopMenuItemIcon = styled(StyledTopMenuItem)`
	font-size: 22px;

	margin-right: 20px;
	margin-top: 5px;
`;

export const StyledTopMenuItemLogo = styled(StyledTopMenuItemIcon)`
	cursor: default;
`;

export const StyledTopMenuItemHamburger = styled(StyledTopMenuItemIcon)`
	@media only screen and (min-width: ${(p) => p.theme.mediumScreenSize}px) {
		display: none;
	}
`;

export const StyledTopMenuSubMenuContainer = styled.div`
	background-color: ${(p) => p.theme.lightGray};
	color: ${(p) => p.theme.primaryColor};

	padding: 10px;
`;

export const StyledTopMenuSubMenuItem = styled(StyledTopMenuItem)`
	display: inline-block;
	
	margin: 0 10px;
`;

export const StyledUserContainer = styled.div`
	display: flex;
	margin-left: auto;

	& > div {
		display: flex;
	}
`;

export const StyledUserMenuContainer = styled.div`
	position: absolute;
	top: 60px;
	right: 0;
	z-index: 8;
	
	width: fit-content;

	text-align: right;

	background-color: ${(p) => p.theme.white};
`;

export const StyledLeftMenuLogo = styled.div`
	height: 40px;
	margin: 10px;

	font-size: 30px;

	text-align: center;
`;

interface IStyledLeftMenu {
	enableLeftMenu: boolean;
	open: boolean;
}

export const StyledLeftMenu = styled.div<IStyledLeftMenu>`
	background-color: ${(p) => p.theme.primaryColor};
	color: ${(p) => p.theme.secondaryColor};

	display: ${(p) => p.open && p.enableLeftMenu ? 'flex' : 'none'};
	flex-direction: column;
	flex-shrink: 0;

	width: ${(p) => p.open && p.enableLeftMenu && 200}px;

	@media only screen and (min-width: ${(p) => p.theme.mediumScreenSize}px) {
		display: ${(p) => p.open || p.enableLeftMenu ? 'flex' : 'none'};

		width: 200px;
	}
`;

interface IStyledLeftMenuItem {
	isChild: boolean;
}

export const StyledLeftMenuItem = styled.div<IStyledLeftMenuItem>`
	margin: 10px 20px 0 ${(p) => p.isChild ? 40 : 20}px;

	display: flex;
	justify-content: space-between;
`;

interface IStyledLeftMenuLabel {
	showPointerCursor: boolean;
}

export const StyledLeftMenuLabel = styled.div<IStyledLeftMenuLabel>`
	vertical-align: middle;

	${(p) => p.showPointerCursor && css`
		cursor: pointer;
	`}
`;

export const StyledLeftMenuIcon = styled.div`
	margin-top: 2px;
	cursor: pointer;
`;

export const StyledUserMenuIcon = styled.div`
	margin-left: 10px;

	cursor: pointer;

	align-self: center;
`;

export const StyledUserMenuLabel = styled.div`
	margin: 5px 20px 0 20px;
	height: 30px;

	cursor: pointer;
`;

interface IStyledRightSide {
	enableLeftMenu: boolean;
	open: boolean;
}

export const StyledRightSide = styled.div<IStyledRightSide>`
	width: 100vw;
	min-height: 100vh;

	display: flex;
	flex-direction: column;

	${(p) => p.open && p.enableLeftMenu && css`
		overflow: hidden;

		&::after {
			content: '';

			position: fixed;
			left: 200px;
			top: 0;
			right: 0;
			bottom: 0;

			background-color: rgba(0, 0, 0, .7);
		}
	`};
`;

interface IStyledPageContent {
	enableLeftMenu: boolean;
	open: boolean;
}

export const StyledPageContent = styled.div<IStyledPageContent>`
	padding-left: 20px;
	padding-right: 20px;

	${(p) => p.open && p.enableLeftMenu && css`
		width: calc(100vw + ${p.open && p.enableLeftMenu ? 200 : 0}px);
	`};
`;
