import { STATUS } from '@romanjaros/treejs-types/common';

import styled, { css } from '../../styled';


export const StyledToasterContainer = styled.div`
	position: fixed;
	bottom: 0;
	right: 0;
	z-index: 9;

	width: calc(100% - 20px);

	margin: 0 10px;

	@media only screen and (min-width: ${(p) => p.theme.tabletScreenSize}px) {
		width: calc((100% / 12  * 6) - 10px);
	}

	@media only screen and (min-width: ${(p) => p.theme.mediumScreenSize}px) {
		width: calc((100% / 12  * 4) - 10px);
	}

	@media only screen and (min-width: ${(p) => p.theme.largeScreenSize}px) {
		width: calc((100% / 12  * 3) - 10px);
	}

	@media only screen and (min-width: ${(p) => p.theme.extraLargeScreenSize}px) {
		width: calc((100% / 12 * 2) - 10px);
	}
`;

interface IStyledToaster {
	status: STATUS;
}

export const StyledToaster = styled.div.attrs({
	className: 'Toaster',
})<IStyledToaster>`
	padding: 16px;

	background-color: ${(p) => p.theme.black};
	color: ${(p) => p.theme.white};

	${(p) => p.status === STATUS.info && css`
		background-color: ${(p) => p.theme.infoColor};
		color: ${(p) => p.theme.white};
	`};

	${(p) => p.status === STATUS.success && css`
		background-color: ${(p) => p.theme.successColor};
		color: ${(p) => p.theme.white};
	`};

	${(p) => p.status === STATUS.warning && css`
		background-color: ${(p) => p.theme.warningColor};
		color: ${(p) => p.theme.white};
	`};

	${(p) => p.status === STATUS.error && css`
		background-color: ${(p) => p.theme.errorColor};
		color: ${(p) => p.theme.white};
	`};

	text-align: center;

	border-radius: 2px;

	margin-bottom: 5px;
`;
